@@ -1,14 +1,14 @@
-from peewee import TextField, ForeignKeyField, CompositeKey
+from peewee import CompositeKey, ForeignKeyField, TextField
 
-from .group import Group
-from .bilibili_user import BilibiliUser
 from ..db import BaseModel
+from .bilibili_user import BilibiliUser
+from .group import Group
 
 
 class FollowLink(BaseModel):
     group = ForeignKeyField(Group, on_delete="CASCADE", backref="followings")
     bilibili_user = ForeignKeyField(BilibiliUser, backref="groups")
-    at_users = TextField()
+    at_users = TextField(default="")
 
     class Meta:
         table_name = "follow_links"
